==> haskell-wai-extra-3.0.20.0-14-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.20.0
id: wai-extra-3.0.20.0-3RsqWfyj5YW2l6djskzmjS
key: wai-extra-3.0.20.0-3RsqWfyj5YW2l6djskzmjS
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
abi: 1dff1369fdaa1f0b9ddfb5c9876e47e4
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/wai-extra-3.0.20.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/wai-extra-3.0.20.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/wai-extra-3.0.20.0
hs-libraries: HSwai-extra-3.0.20.0-3RsqWfyj5YW2l6djskzmjS
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM time-1.8.0.2
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx directory-1.3.0.2
    transformers-0.5.2.0 blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7
    wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs
    ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    void-0.7.2-KNNEd7XG9bDRysTndgnf2
    stringsearch-0.3.6.6-K30MyFaBEiEDdRa9SPnW19 containers-0.5.10.2
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    word8-0.1.3-CN5TjopM0jqExzuBsYZ0mY
    lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ deepseq-1.4.3.0
    streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
    cookie-0.4.2.1-EtHMWPQIghd9pOfnkVb7tc
    vault-0.3.0.7-UMEOtujMAKHj95FR8j5G
    zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am unix-2.7.2.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=b2b1b36770028b18814f7469d1a17fa5
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=bb3d8fbe7de4d3cc9ed854226de736b7
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl=5f0b9ac0c18ceda00944b15fba2a2195
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=c240e412bac64503e37397debf06fa14
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=55d8edbe337279f21d58496f3f779cb9
             fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7=4fe9e3cb4687ed21d88fd96f3fa94e5f
             wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs=980351279c4942632d0628edb229e7b9
             ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU=8d42c7012ae6bb1dfca5905fe8a25762
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             void-0.7.2-KNNEd7XG9bDRysTndgnf2=bfdecfdd320edc5290f0eb88b00ff7c3
             stringsearch-0.3.6.6-K30MyFaBEiEDdRa9SPnW19=a969b20cb22a64cb5966053fb82fb14e
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             word8-0.1.3-CN5TjopM0jqExzuBsYZ0mY=c674ac3552620af97a08fc348e4f8b97
             lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ=bb85cfc6c0da3429f07db4d32d334f57
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4=e456784a917b058dfa9cbf83d08f1715
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=de9563896484115ad3fe305bce9cecd3
             cookie-0.4.2.1-EtHMWPQIghd9pOfnkVb7tc=b4cec15972259e142a0c3a4845b57827
             vault-0.3.0.7-UMEOtujMAKHj95FR8j5G=2b12ec69f6e0b19cbd0b6c6fe34b94b7
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=c1d55c3251ed960ccd96b402a1d90259
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am=597f66fc6d9460f7765410dd4acfa3cc
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.0.20.0-15-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.20.0
id: wai-extra-3.0.20.0-BsgGxPimsjqDT3aPQxdXol
key: wai-extra-3.0.20.0-BsgGxPimsjqDT3aPQxdXol
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
abi: 257c1745e31e44c67121831897e26666
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/wai-extra-3.0.20.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/wai-extra-3.0.20.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/wai-extra-3.0.20.0
hs-libraries: HSwai-extra-3.0.20.0-BsgGxPimsjqDT3aPQxdXol
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM time-1.8.0.2
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx directory-1.3.0.2
    transformers-0.5.2.0 blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7
    wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs
    ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    void-0.7.2-KNNEd7XG9bDRysTndgnf2
    stringsearch-0.3.6.6-K30MyFaBEiEDdRa9SPnW19 containers-0.5.10.2
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    word8-0.1.3-CN5TjopM0jqExzuBsYZ0mY
    lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ deepseq-1.4.3.0
    streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
    cookie-0.4.2.1-EtHMWPQIghd9pOfnkVb7tc
    vault-0.3.0.7-UMEOtujMAKHj95FR8j5G
    zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am unix-2.7.2.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=b2b1b36770028b18814f7469d1a17fa5
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=bb3d8fbe7de4d3cc9ed854226de736b7
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl=5f0b9ac0c18ceda00944b15fba2a2195
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=c240e412bac64503e37397debf06fa14
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=55d8edbe337279f21d58496f3f779cb9
             fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7=4fe9e3cb4687ed21d88fd96f3fa94e5f
             wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs=980351279c4942632d0628edb229e7b9
             ansi-terminal-0.6.3.1-BIEgiaci8VQ7yyITu4jhfU=8d42c7012ae6bb1dfca5905fe8a25762
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             void-0.7.2-KNNEd7XG9bDRysTndgnf2=bfdecfdd320edc5290f0eb88b00ff7c3
             stringsearch-0.3.6.6-K30MyFaBEiEDdRa9SPnW19=a969b20cb22a64cb5966053fb82fb14e
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             word8-0.1.3-CN5TjopM0jqExzuBsYZ0mY=c674ac3552620af97a08fc348e4f8b97
             lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ=bb85cfc6c0da3429f07db4d32d334f57
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4=e456784a917b058dfa9cbf83d08f1715
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=de9563896484115ad3fe305bce9cecd3
             cookie-0.4.2.1-EtHMWPQIghd9pOfnkVb7tc=b4cec15972259e142a0c3a4845b57827
             vault-0.3.0.7-UMEOtujMAKHj95FR8j5G=2b12ec69f6e0b19cbd0b6c6fe34b94b7
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=c1d55c3251ed960ccd96b402a1d90259
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am=597f66fc6d9460f7765410dd4acfa3cc
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
